@@ -19,8 +19,7 @@ else:
     FINTIX_IO_DATA_DIR = "/var/lib/fintix"
     FINTIX_IO_LOG_DIR = "/var/log/fintix"
 
-LOCAL_DEPLOY_MODEL_REPO = os.path.join(FINTIX_IO_DATA_DIR, "models", "deploy")
-LOCAL_TRAINING_MODEL_REPO = os.path.join(FINTIX_IO_DATA_DIR, "models", "train")
+LOCAL_DEPLOY_MODEL_REPO = os.path.join(FINTIX_IO_DATA_DIR, "models")
 
 MILLISECOND_PER_UNIT = {
     "s": 1000,
