@@ -129,10 +129,10 @@ class ModelRepository:
             if should_update:
                 logging.info(f"Model '{model_name}' already exist! Update model to newer version.")
                 cur.execute(
-                    f"UPDATE io_fintix.custom_model SET model=%s WHERE model_uid='{model_name}'",(script_content))
+                    f"UPDATE io_fintix.custom_model SET model=%s WHERE model_uid=%s", (script_content, model_name))
             else:
                 logging.info(f"Model '{model_name}' does not exist! Insert new model into database.")
-                cur.execute(f"INSERT INTO io_fintix.custom_model (model_uid, model_name, model) VALUES('{model_name}', '{model_name}', %s)", (script_content))
+                cur.execute(f"INSERT INTO io_fintix.custom_model (model_uid, model_name, model) VALUES(%s, %s, %s)", (model_name, model_name, script_content))
             conn.commit()
             logging.info(f"Successfully upload converted python script of model '{model_name}' notebook into database")
         except Exception as e:
